@@ -40,10 +40,14 @@ require "$SCRIPTSDIR/xml.pl$DOTIN";
 $PLATFORM_INFO = {
   "debian-2.2"      => "Debian GNU/Linux 2.2 Potato",
   "debian-3.0"      => "Debian GNU/Linux 3.0 Woody",
-  "debian-sarge"    => "Debian GNU/Linux Sarge",
-  "ubuntu-5.04"     => "Ubuntu GNU/Linux Hoary",
-  "ubuntu-5.10"     => "Ubuntu GNU/Linux Breezy",
-  "ubuntu-6.06"     => "Ubuntu GNU/Linux Dapper",
+  "debian-3.1"      => "Debian GNU/Linux 3.1 Sarge",
+  "debian-4.0"      => "Debian GNU/Linux 4.0 Etch",
+  "debian-testing"  => "Debian GNU/Linux Testing/Unstable",
+  "ubuntu-5.04"     => "Ubuntu 5.04, Hoary Hedgehog",
+  "ubuntu-5.10"     => "Ubuntu 5.10, Breezy Badger",
+  "ubuntu-6.06"     => "Ubuntu 6.06, Dapper Drake",
+  "ubuntu-6.10"     => "Ubuntu 6.10, Edgy Eft",
+  "ubuntu-7.04"     => "Ubuntu 7.04, Feisty Fawn",
   "redhat-5.2"      => "Red Hat Linux 5.2 Apollo",
   "redhat-6.0"      => "Red Hat Linux 6.0 Hedwig",
   "redhat-6.1"      => "Red Hat Linux 6.1 Cartman",
@@ -66,6 +70,8 @@ $PLATFORM_INFO = {
   "mandrake-10.2"   => "Linux Mandrake 2005 LE",
   "mandriva-2006.0" => "Mandriva Linux 2006.0",
   "mandriva-2006.1" => "Mandriva Linux 2006.1",
+  "mandriva-2007.0" => "Mandriva Linux 2007.0",
+  "mandriva-2007.1" => "Mandriva Linux 2007.1",
   "yoper-2.2"       => "Yoper Linux 2.2",
   "blackpanther-4.0" => "Black Panther OS 4.0",
   "conectiva-9"     => "Conectiva Linux 9",
@@ -128,8 +134,9 @@ sub check_debian
 {
   my ($ver, $i);
   my %vermap =
-      ("testing/unstable" => "sarge",
-       "3.1"              => "sarge");
+      ("testing/unstable" => "testing",
+       "3.1"              => "sarge",
+       "4.0"              => "etch");
 
   open DEBIAN, "$gst_prefix/etc/debian_version" or return -1;
   chomp ($ver = <DEBIAN>);
