@@ -70,7 +70,8 @@ sub gst_service_sysv_get_paths
        "mandrake-10.2" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
        "mandriva-2006.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
        "mandriva-2006.1" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
-
+       "mandriva-2007.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+       "mandriva-2007.1" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
        "yoper-2.2" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
 
        "blackpanther-4.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
@@ -80,10 +81,14 @@ sub gst_service_sysv_get_paths
 
        "debian-2.2"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "debian-3.0"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
-       "debian-sarge" => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
+       "debian-3.1"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
+       "debian-4.0"   => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
+       "debian-testing" => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "ubuntu-5.04"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "ubuntu-5.10"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "ubuntu-6.06"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
+       "ubuntu-6.10"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
+       "ubuntu-7.04"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        
        "suse-7.0"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d", "../"],
        "suse-9.0"     => ["$gst_prefix/etc/init.d", "$gst_prefix/etc/init.d", "../"],
@@ -141,6 +146,8 @@ sub gst_service_sysv_get_runlevels
        "mandrake-10.2"  => [3, 5],
        "mandriva-2006.0"  => [3, 5],
        "mandriva-2006.1"  => [3, 5],
+       "mandriva-2007.0"  => [3, 5],
+       "mandriva-2007.1"  => [3, 5],
 
        "yoper-2.2"  => [3, 5],
 
@@ -151,10 +158,14 @@ sub gst_service_sysv_get_runlevels
 
        "debian-2.2"     => [2, 3],
        "debian-3.0"     => [2, 3],
-       "debian-sarge"   => [2, 3],
+       "debian-3.1"     => [2, 3],
+       "debian-4.0"     => [2, 3],
+       "debian-testing" => [2, 3],
        "ubuntu-5.04"    => [2, 3],
        "ubuntu-5.10"    => [2, 3],
-       "ubuntu-6.04"    => [2, 3],
+       "ubuntu-6.06"    => [2, 3],
+       "ubuntu-6.10"    => [2, 3],
+       "ubuntu-7.04"    => [2, 3],
        
        "suse-7.0"       => [3, 5],
        "suse-9.0"       => [3, 5],
@@ -211,6 +222,8 @@ sub gst_service_get_runlevel_roles
      "mandrake-10.2"  => "redhat-5.2",
      "mandriva-2006.0"  => "redhat-5.2",
      "mandriva-2006.1"  => "redhat-5.2",
+     "mandriva-2007.0"  => "redhat-5.2",
+     "mandriva-2007.1"  => "redhat-5.2",
 
      "yoper-2.2"  => "redhat-5.2",
  
@@ -221,10 +234,14 @@ sub gst_service_get_runlevel_roles
      
      "debian-2.2"     => "debian-2.2",
      "debian-3.0"     => "debian-2.2",
-     "debian-sarge"   => "debian-2.2",
+     "debian-3.1"     => "debian-2.2",
+     "debian-4.0"     => "debian-2.2",
+     "debian-testing" => "debian-2.2",
      "ubuntu-5.04"    => "debian-2.2",
      "ubuntu-5.10"    => "debian-2.2",
-     "ubuntu-6.04"    => "debian-2.2",
+     "ubuntu-6.06"    => "debian-2.2",
+     "ubuntu-6.10"    => "debian-2.2",
+     "ubuntu-7.04"    => "debian-2.2",
           
      "suse-7.0"       => "redhat-5.2",
      "suse-9.0"       => "redhat-5.2",
@@ -1696,10 +1713,14 @@ sub gst_service_get_status
       (
        "debian-2.2"   => \&gst_service_debian_get_status,
        "debian-3.0"   => \&gst_service_debian_get_status,
-       "debian-sarge" => \&gst_service_debian_get_status,
+       "debian-3.1"   => \&gst_service_debian_get_status,
+       "debian-4.0"   => \&gst_service_debian_get_status,
+       "debian-testing" => \&gst_service_debian_get_status,
        "ubuntu-5.04"  => \&gst_service_debian_get_status,
        "ubuntu-5.10"  => \&gst_service_debian_get_status,
-       "ubuntu-6.04"  => \&gst_service_debian_get_status,
+       "ubuntu-6.06"  => \&gst_service_debian_get_status,
+       "ubuntu-6.10"  => \&gst_service_debian_get_status,
+       "ubuntu-7.04"  => \&gst_service_debian_get_status,
               
        "redhat-5.2"   => \&gst_service_redhat_get_status,
        "redhat-6.0"   => \&gst_service_redhat_get_status,
